﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;



namespace ColorComboBoxTest
{
    public partial class MainForm : Form
    {
        private DataTable _testTable = null;
        private BindingSource _testSource = null;
        private int _drawItemCounter = 0;

        // КОНСТРУКТОР
        public MainForm()
        {
            InitializeComponent();

            // тестовая таблица с тестовыми данными
            _testTable = new DataTable();
            _testTable.Columns.Add(new DataColumn("ID", System.Type.GetType("System.Int32")));
            _testTable.Columns.Add(new DataColumn("TYPE", System.Type.GetType("System.Int32")));
            _testTable.Columns.Add(new DataColumn("TEXT", System.Type.GetType("System.String")));

            for (int counter = 1; counter <= 10; counter++)
            {
                DataRow rowToAdd = _testTable.NewRow();
                rowToAdd["ID"] = counter;

                // для теста переусложнено но в реальности тип вовсе не обязательно будет зависеть от кода строки и вообще быть числом
                int type = 0;
                if (counter > 3 && counter < 7)
                {
                    type = 1;
                }
                else if (counter >= 7)
                {
                    type = 2;
                }
                rowToAdd["TYPE"] = type;


                rowToAdd["TEXT"] = "Тестовая строка № " + counter  + " с типом " + type;
                _testTable.Rows.Add(rowToAdd);
            }

            _testSource = new BindingSource();
            _testSource.DataSource = _testTable;

            _testComboBox.DisplayMember = "TEXT";
            _testComboBox.ValueMember = "ID";
            _testComboBox.DataSource = _testSource;

            // чтобы происходило событие для раскраски, можно и через дизайнер
            _testComboBox.DrawMode = DrawMode.OwnerDrawVariable;


            // упрощенный вариант при заполнении комбо-бокса вручную
            for (int counter = 1; counter <= 10; counter++)
            {
                _testNonBindedComboBox.Items.Add(counter.ToString());
            }
            _testNonBindedComboBox.SelectedIndex = 3;
            _testNonBindedComboBox.DrawMode = DrawMode.OwnerDrawVariable;

            // end  public MainForm()
        }

        //РАСКРАСКА КОМБО_БОКСА СОБЫТИЕ ПРОРИСОВКИ ЭЛЕМЕНТА
        private void _testComboBox_DrawItem(object sender, DrawItemEventArgs e)
        {
            _drawItemCounter++;
            _drawItemCounterLabel.Text = "Всего срабатываний DrawItem: " + _drawItemCounter;

            e.DrawBackground();

            // в событие комбобокс передается в универсальнмо типе Object, конвертируем в комбо-бокс
            ComboBox currComboBox = (ComboBox)sender;

            // вернет System.DataRow.DataRowView так как на самом деле там сидит обьект класса DataRowView
            //string text = currComboBox.Items[e.Index].ToString();

            DataRowView currItemDRView = (DataRowView)currComboBox.Items[e.Index];
            string text = currItemDRView.Row["TEXT"].ToString();
            int id = Convert.ToInt32(currItemDRView.Row["ID"]);



            // к сожалению прямым путем ValueMember для текущего item не получить
            int type = 0;
            foreach (DataRow currRow in _testTable.Rows)
            {
                int currId = (int)currRow["ID"];

                if (currId == id)
                {
                    type = (int)currRow["TYPE"];
                    break;
                }
            }

            // определяем цвет для текущей строки  
            Brush brush;
            if (type == 0)
            {
                brush = Brushes.Red;
            }
            else if (type == 1)
            {
                brush = Brushes.Green;
            }
            else 
            {
                brush = Brushes.Blue;
            }

            // прорисовываем текст в строке комбо-бокса
            e.Graphics.DrawString(text, currComboBox.Font, brush, e.Bounds.X, e.Bounds.Y);
        }




        // УПРЩЕННАЯ РАСКРАСКА КОМБОБОКСА ПРОСТО ПО КОЛЛЕКЦИИ ЕГО ЭЛЕМЕНТОВ-СТРОК
        private void _testNonBindedComboBox_DrawItem(object sender, DrawItemEventArgs e)
        {
            _drawItemCounter++;
            _drawItemCounterLabel.Text = "Всего срабатываний DrawItem: " + _drawItemCounter;

            // в событие комбобокс передается в универсальнмо типе Object, конвертируем в комбо-бокс
            ComboBox currComboBox = (ComboBox)sender;

            string text = currComboBox.Items[e.Index].ToString();
            int textInteger = Convert.ToInt32(text);

            // определяем цвет для текущей строки  
            Brush brush;
            if (textInteger < 3)
            {
                brush = Brushes.Red;
            }
            else if (textInteger > 3 && textInteger < 6)
            {
                brush = Brushes.Green;
            }
            else
            {
                brush = Brushes.Blue;
            }

            // чтобы это событие происходило необходимо поставить свойствоа комбо-бокса DrawMode в OwnerDrawFixed/OwnerDrawVariable 
            e.DrawBackground();
            // прорисовываем текст в строке комбо-бокса
            e.Graphics.DrawString(text, currComboBox.Font, brush, e.Bounds.X, e.Bounds.Y);
        }

        // end public partial class MainForm : Form
    }
}
